@@ -10,6 +10,7 @@ use URI::Escape ();
 use Amon2::Web::Request;
 use Amon2::Web::Response;
 use Scalar::Util ();
+use Plack::Session;
 
 # -------------------------------------------------------------------------
 # hook points:
@@ -25,6 +26,11 @@ BEGIN {
     sub encoding          { $encoding }
 }
 
+sub session {
+	my $self = shift;
+	$self->{session} ||= Plack::Session->new($self->request->env);
+}
+
 # -------------------------------------------------------------------------
 # attributes
 sub request           { $_[0]->{request} }
